@@ -264,6 +264,15 @@ def parse_args(gerrit_config):
         default="clang-tidy",
         help="Name of the checker use for producing review"
     )
+    review_parser.add_argument(
+        "--robot_run_id",
+        dest="robot_run_id",
+        action="store",
+        type=str,
+        metavar="N",
+        default="Unspecified",
+        help="Run ID shown in the gerrit message"
+    )
     review_parser.set_defaults(cmd=review)
 
     runverify_parser = sub_parsers.add_parser(
@@ -468,7 +477,7 @@ def get_changes_submitted_together(rest, changeid):
             raise RuntimeError(f"Provided change ({changeid}) cannot be found on remote gerrit server.")
 
 
-def _get_payload(payload_json, path_prefixes, robot_id):
+def _get_payload(payload_json, path_prefixes, robot_id, robot_run_id):
     def trim_prefixes(name, prefixes):
         for prefix in prefixes:
             name = name.lstrip(prefix)
@@ -499,7 +508,7 @@ def _get_payload(payload_json, path_prefixes, robot_id):
             if res:
                 item["message"] = f"{res.group('prio')} {res.group('msg')}"
             item["robot_id"] = robot_id
-            item["robot_run_id"] = get_json_sem_hash(item)[0:8]
+            item["robot_run_id"] = robot_run_id
 
         payload["robot_comments"][new_key] = comments[key].copy()
 
@@ -528,7 +537,7 @@ def review(rest, git_repo, args, gerrit_config):
 
     change_details = get_change_detail(rest, args.changeid)
     rev = get_rev(change_details)
-    payload = _get_payload(args.payload, args.path_prefixes, args.robot_id)
+    payload = _get_payload(args.payload, args.path_prefixes, args.robot_id, args.robot_run_id)
     payload["omit_duplicate_comments"] = True
     payload["notify"] = "OWNER"
 
